%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% Subversion file information - please do not edit this block
%% $Rev: 882 $
%% $Date: 2011-01-10 09:06:33 +0100 (Mon, 10 Jan 2011) $
%% $Author: nash $
%% $Id: indbExposure.Rd 882 2011-01-10 08:06:33Z nash $
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\name{indbExposure}
\alias{indbExposure}
\title{
  Calculate estimated female population exposures
}
\description{
  This function calculates estimated female population exposures using the methodology
  described in the Methods Protocol for the Human Fertility Database. The exposures
  are estimated based on population estimates and death counts from the Human Mortality
  Database together with, where available, data on monthly births from the HFD.
}
\usage{
indbExposure(pop, monthlyBirths = NULL, tAdj = NULL, outfile = NULL, countryCode = "XXX", verbose = TRUE)
}
\arguments{
  \item{pop}{
  The path to a Human Mortality Database LexisDB file of female population and deaths, or
  a data frame representing this
}
  \item{monthlyBirths}{
  The path to a HFD input file of monthly births, or a data frame representing this
}
  \item{tAdj}{
  The path to a Human Mortality Database territorial adjustment factor file, or a data
  frame representing this
}
  \item{outfile}{
  The path to a file where the resulting exposure estimates should be written
}
  \item{countryCode}{
  The (usually alpha-3) code of the population for which exposures will be estimated
}
  \item{verbose}{
  Whether progress should be reported (usually in the form of a progress bar)
}
}
\details{
  The expected formats of \code{pop}, \code{tAdj} and \code{monthlyBirths} may be found
  in the documentation of the Human Mortality Database and Human Fertility Database
  projects.
  
  If \code{outfile} is \code{NULL}, a filename of [countryCode]exp.txt in the working
  directory will be used. To suppress file output, set \code{outfile} to \code{NA}.
  
  If \code{countryCode} is not supplied, an attempt will be made to infer it
  from one of the inputs (\code{pop}, \code{monthlyBirths}, code{tAdj}).
}
\value{
  A data frame containing the columns Year, Age, Cohort and Exposure. Additionally
  the data may be written to file.
}
\references{
  Jasilioniene et al.: Methods Protocol for the Human Fertility Database and
  HFD data formats documentation, both available from \url{http://www.humanfertility.org}
  Human Mortality Database documentation is available from \url{http://www.mortality.org} 
}
\author{
Edward Nash \email{nash@demogr.mpg.de}
}
\examples{
\dontrun{
# requires files fUSA.txt and USAtadj.txt from HMD
# and file USAmonthly.txt from HFD
indbExposure("fUSA.txt", "USAmonthly.txt", "USAtadj.txt", "USAexp.txt", "USA", TRUE)
}
}
